spannertools.OctavationSpanner
==============================

.. abjad-lineage:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner

.. autoclass:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.adjust_automatically
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.components
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.start
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.stop
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__contains__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__copy__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__eq__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__format__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__getitem__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__hash__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__len__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__lt__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__ne__
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.start
   :noindex:

.. autoattribute:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.stop
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.adjust_automatically
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__hash__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.__repr__
   :noindex:
